"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostByOrgByRepoSyncRequestTypedDict(TypedDict):
    org: str
    repo: str


class PostByOrgByRepoSyncRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class PostByOrgByRepoSyncInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoSyncBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoSyncResponseTypedDict(TypedDict):
    r"""Sync completed successfully"""

    success: Literal[True]


class PostByOrgByRepoSyncResponse(BaseModel):
    r"""Sync completed successfully"""

    success: Annotated[
        Annotated[Literal[True], AfterValidator(validate_const(True))],
        pydantic.Field(alias="success"),
    ] = True



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import postbyorgapikeysop as models_postbyorgapikeysop
from mesa_sdk.types import BaseModel
from typing import Optional


class PostByOrgAPIKeysInternalServerErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysInternalServerErrorError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysInternalServerError(MesaError):
    r"""Internal error"""

    data: PostByOrgAPIKeysInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysConflictErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysConflictError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysConflictError(MesaError):
    r"""Conflict"""

    data: PostByOrgAPIKeysConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysNotAcceptableErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysNotAcceptableError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: PostByOrgAPIKeysNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysNotFoundErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysNotFoundError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysNotFoundError(MesaError):
    r"""Not found"""

    data: PostByOrgAPIKeysNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysForbiddenErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysForbiddenError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysForbiddenError(MesaError):
    r"""Forbidden"""

    data: PostByOrgAPIKeysForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysUnauthorizedErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysUnauthorizedError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: PostByOrgAPIKeysUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgAPIKeysBadRequestErrorData(BaseModel):
    error: models_postbyorgapikeysop.PostByOrgAPIKeysBadRequestError


@dataclass(unsafe_hash=True)
class PostByOrgAPIKeysBadRequestError(MesaError):
    r"""Invalid request"""

    data: PostByOrgAPIKeysBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgAPIKeysBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    deletebyorgbyrepowebhooksbywebhookidop as models_deletebyorgbyrepowebhooksbywebhookidop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError(MesaError):
    r"""Internal error"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData = field(
        hash=False
    )

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDConflictError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDConflictError(MesaError):
    r"""Conflict"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError(MesaError):
    r"""Not found"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError(MesaError):
    r"""Forbidden"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData(BaseModel):
    error: models_deletebyorgbyrepowebhooksbywebhookidop.DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError(MesaError):
    r"""Invalid request"""

    data: DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import httpx
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    validate_const,
)
import pydantic
from pydantic import Field, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class GetByOrgByRepoContentRequestTypedDict(TypedDict):
    org: str
    repo: str
    ref: NotRequired[str]
    path: NotRequired[str]
    depth: NotRequired[int]


class GetByOrgByRepoContentRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    ref: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    path: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    depth: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["ref", "path", "depth"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoContentBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoContentBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class EntryDirTypedDict(TypedDict):
    name: str
    path: str
    sha: str
    type: Literal["dir"]


class EntryDir(BaseModel):
    name: str

    path: str

    sha: str

    type: Annotated[
        Annotated[Literal["dir"], AfterValidator(validate_const("dir"))],
        pydantic.Field(alias="type"),
    ] = "dir"


class EntrySymlinkTypedDict(TypedDict):
    name: str
    path: str
    sha: str
    size: float
    executable: bool
    last_commit_at: Nullable[datetime]
    type: Literal["symlink"]


class EntrySymlink(BaseModel):
    name: str

    path: str

    sha: str

    size: float

    executable: bool

    last_commit_at: Nullable[datetime]

    type: Annotated[
        Annotated[Literal["symlink"], AfterValidator(validate_const("symlink"))],
        pydantic.Field(alias="type"),
    ] = "symlink"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class EntryFileTypedDict(TypedDict):
    name: str
    path: str
    sha: str
    size: float
    executable: bool
    last_commit_at: Nullable[datetime]
    type: Literal["file"]


class EntryFile(BaseModel):
    name: str

    path: str

    sha: str

    size: float

    executable: bool

    last_commit_at: Nullable[datetime]

    type: Annotated[
        Annotated[Literal["file"], AfterValidator(validate_const("file"))],
        pydantic.Field(alias="type"),
    ] = "file"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


EntryTypedDict = TypeAliasType(
    "EntryTypedDict",
    Union[EntryDirTypedDict, EntryFileTypedDict, EntrySymlinkTypedDict],
)


Entry = Annotated[Union[EntryFile, EntrySymlink, EntryDir], Field(discriminator="type")]


class DirTypedDict(TypedDict):
    name: str
    path: str
    sha: str
    child_count: int
    entries: List[EntryTypedDict]
    type: Literal["dir"]


class Dir(BaseModel):
    name: str

    path: str

    sha: str

    child_count: int

    entries: List[Entry]

    type: Annotated[
        Annotated[Literal["dir"], AfterValidator(validate_const("dir"))],
        pydantic.Field(alias="type"),
    ] = "dir"


class SymlinkBase64TypedDict(TypedDict):
    name: str
    path: str
    sha: str
    size: float
    content: str
    executable: bool
    last_commit_at: Nullable[datetime]
    type: Literal["symlink"]
    encoding: Literal["base64"]


class SymlinkBase64(BaseModel):
    name: str

    path: str

    sha: str

    size: float

    content: str

    executable: bool

    last_commit_at: Nullable[datetime]

    type: Annotated[
        Annotated[Literal["symlink"], AfterValidator(validate_const("symlink"))],
        pydantic.Field(alias="type"),
    ] = "symlink"

    encoding: Annotated[
        Annotated[Literal["base64"], AfterValidator(validate_const("base64"))],
        pydantic.Field(alias="encoding"),
    ] = "base64"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class FileBase64TypedDict(TypedDict):
    name: str
    path: str
    sha: str
    size: float
    content: str
    executable: bool
    last_commit_at: Nullable[datetime]
    type: Literal["file"]
    encoding: Literal["base64"]


class FileBase64(BaseModel):
    name: str

    path: str

    sha: str

    size: float

    content: str

    executable: bool

    last_commit_at: Nullable[datetime]

    type: Annotated[
        Annotated[Literal["file"], AfterValidator(validate_const("file"))],
        pydantic.Field(alias="type"),
    ] = "file"

    encoding: Annotated[
        Annotated[Literal["base64"], AfterValidator(validate_const("base64"))],
        pydantic.Field(alias="encoding"),
    ] = "base64"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


GetByOrgByRepoContentResponseBodyTypedDict = TypeAliasType(
    "GetByOrgByRepoContentResponseBodyTypedDict",
    Union[DirTypedDict, FileBase64TypedDict, SymlinkBase64TypedDict],
)
r"""Content response"""


GetByOrgByRepoContentResponseBody = Annotated[
    Union[FileBase64, SymlinkBase64, Dir], Field(discriminator="type")
]
r"""Content response"""


GetByOrgByRepoContentResponseTypedDict = TypeAliasType(
    "GetByOrgByRepoContentResponseTypedDict",
    Union[GetByOrgByRepoContentResponseBodyTypedDict, httpx.Response],
)


GetByOrgByRepoContentResponse = TypeAliasType(
    "GetByOrgByRepoContentResponse",
    Union[GetByOrgByRepoContentResponseBody, httpx.Response],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import deletebyorgapikeysbyidop as models_deletebyorgapikeysbyidop
from mesa_sdk.types import BaseModel
from typing import Optional


class DeleteByOrgAPIKeysByIDInternalServerErrorData(BaseModel):
    error: (
        models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDInternalServerError(MesaError):
    r"""Internal error"""

    data: DeleteByOrgAPIKeysByIDInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDConflictErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDConflictError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDConflictError(MesaError):
    r"""Conflict"""

    data: DeleteByOrgAPIKeysByIDConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDNotAcceptableErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDNotAcceptableError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: DeleteByOrgAPIKeysByIDNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDNotFoundErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDNotFoundError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDNotFoundError(MesaError):
    r"""Not found"""

    data: DeleteByOrgAPIKeysByIDNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDForbiddenErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDForbiddenError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDForbiddenError(MesaError):
    r"""Forbidden"""

    data: DeleteByOrgAPIKeysByIDForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDUnauthorizedErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDUnauthorizedError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: DeleteByOrgAPIKeysByIDUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgAPIKeysByIDBadRequestErrorData(BaseModel):
    error: models_deletebyorgapikeysbyidop.DeleteByOrgAPIKeysByIDBadRequestError


@dataclass(unsafe_hash=True)
class DeleteByOrgAPIKeysByIDBadRequestError(MesaError):
    r"""Invalid request"""

    data: DeleteByOrgAPIKeysByIDBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgAPIKeysByIDBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepowebhooksop as models_getbyorgbyrepowebhooksop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoWebhooksInternalServerErrorData(BaseModel):
    error: (
        models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoWebhooksInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksConflictErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoWebhooksConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoWebhooksNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoWebhooksNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoWebhooksForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoWebhooksUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoWebhooksBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepowebhooksop.GetByOrgByRepoWebhooksBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoWebhooksBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoWebhooksBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoWebhooksBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from pydantic import model_serializer
from typing import Any, Dict, List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


Scope = Literal[
    "git:read",
    "git:write",
    "repo:read",
    "repo:create",
    "repo:delete",
    "webhook:read",
    "webhook:write",
    "admin",
]


class PostByOrgAPIKeysRequestBodyTypedDict(TypedDict):
    name: NotRequired[str]
    scopes: NotRequired[List[Scope]]


class PostByOrgAPIKeysRequestBody(BaseModel):
    name: Optional[str] = None

    scopes: Optional[List[Scope]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["name", "scopes"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysRequestTypedDict(TypedDict):
    org: str
    body: NotRequired[PostByOrgAPIKeysRequestBodyTypedDict]


class PostByOrgAPIKeysRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body: Annotated[
        Optional[PostByOrgAPIKeysRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgAPIKeysBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgAPIKeysResponseTypedDict(TypedDict):
    r"""API key created"""

    id: str
    key: str
    name: Nullable[str]
    scopes: List[str]
    created_at: str


class PostByOrgAPIKeysResponse(BaseModel):
    r"""API key created"""

    id: str

    key: str

    name: Nullable[str]

    scopes: List[str]

    created_at: str

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mesa_sdk import errors, models, utils
from mesa_sdk._hooks import HookContext
from mesa_sdk.types import OptionalNullable, UNSET
from mesa_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class AgentBlame(BaseSDK):
    def get_by_org_by_repo_agentblame(
        self,
        *,
        org: str,
        repo: str,
        base: str,
        head: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoAgentblameResponse:
        r"""Get AI attribution data

        Retrieve agentblame attribution data for commits between two refs

        :param org:
        :param repo:
        :param base:
        :param head:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoAgentblameRequest(
            org=org,
            repo=repo,
            base=base,
            head=head,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/{repo}/agentblame",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoAgentblame",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoAgentblameResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def get_by_org_by_repo_agentblame_async(
        self,
        *,
        org: str,
        repo: str,
        base: str,
        head: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoAgentblameResponse:
        r"""Get AI attribution data

        Retrieve agentblame attribution data for commits between two refs

        :param org:
        :param repo:
        :param base:
        :param head:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoAgentblameRequest(
            org=org,
            repo=repo,
            base=base,
            head=head,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/{repo}/agentblame",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoAgentblame",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoAgentblameResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAgentblameInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoAgentblameInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def get_by_org_by_repo_analytics(
        self,
        *,
        org: str,
        repo: str,
        period: Optional[models.Period] = "all",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoAnalyticsResponse:
        r"""Get repository analytics

        Retrieve repository-wide AI attribution analytics from agentblame

        :param org:
        :param repo:
        :param period:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoAnalyticsRequest(
            org=org,
            repo=repo,
            period=period,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/{repo}/analytics",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoAnalytics",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoAnalyticsResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def get_by_org_by_repo_analytics_async(
        self,
        *,
        org: str,
        repo: str,
        period: Optional[models.Period] = "all",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoAnalyticsResponse:
        r"""Get repository analytics

        Retrieve repository-wide AI attribution analytics from agentblame

        :param org:
        :param repo:
        :param period:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoAnalyticsRequest(
            org=org,
            repo=repo,
            period=period,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/{repo}/analytics",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoAnalytics",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.GetByOrgByRepoAnalyticsResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoAnalyticsInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoAnalyticsInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def post_by_org_by_repo_analytics_refresh(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoAnalyticsRefreshResponse:
        r"""Refresh repository analytics

        Trigger a full re-aggregation of repository analytics

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoAnalyticsRefreshRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="POST",
            path="/{org}/{repo}/analytics/refresh",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoAnalyticsRefresh",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.PostByOrgByRepoAnalyticsRefreshResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshForbiddenError(
                response_data, http_res
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshNotFoundError(
                response_data, http_res
            )
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshConflictError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def post_by_org_by_repo_analytics_refresh_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoAnalyticsRefreshResponse:
        r"""Refresh repository analytics

        Trigger a full re-aggregation of repository analytics

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoAnalyticsRefreshRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/{repo}/analytics/refresh",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoAnalyticsRefresh",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.PostByOrgByRepoAnalyticsRefreshResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshBadRequestError(
                response_data, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshUnauthorizedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshForbiddenError(
                response_data, http_res
            )
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshNotFoundError(
                response_data, http_res
            )
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshNotAcceptableError(
                response_data, http_res
            )
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshConflictError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoAnalyticsRefreshInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoAnalyticsRefreshInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepodiffop as models_getbyorgbyrepodiffop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoDiffInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoDiffInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffConflictErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoDiffConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoDiffNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoDiffNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoDiffForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoDiffUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoDiffBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepodiffop.GetByOrgByRepoDiffBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoDiffBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoDiffBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoDiffBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import patchbyorgbyrepoop as models_patchbyorgbyrepoop
from mesa_sdk.types import BaseModel
from typing import Optional


class PatchByOrgByRepoInternalServerErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoInternalServerErrorError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoInternalServerError(MesaError):
    r"""Internal error"""

    data: PatchByOrgByRepoInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoConflictErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoConflictError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoConflictError(MesaError):
    r"""Conflict"""

    data: PatchByOrgByRepoConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoNotAcceptableErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoNotAcceptableError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: PatchByOrgByRepoNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoNotFoundErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoNotFoundError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoNotFoundError(MesaError):
    r"""Not found"""

    data: PatchByOrgByRepoNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoForbiddenErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoForbiddenError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoForbiddenError(MesaError):
    r"""Forbidden"""

    data: PatchByOrgByRepoForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoUnauthorizedErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoUnauthorizedError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: PatchByOrgByRepoUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PatchByOrgByRepoBadRequestErrorData(BaseModel):
    error: models_patchbyorgbyrepoop.PatchByOrgByRepoBadRequestError


@dataclass(unsafe_hash=True)
class PatchByOrgByRepoBadRequestError(MesaError):
    r"""Invalid request"""

    data: PatchByOrgByRepoBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: PatchByOrgByRepoBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import postbyorgreposop as models_postbyorgreposop
from mesa_sdk.types import BaseModel
from typing import Optional


class PostByOrgReposInternalServerErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposInternalServerErrorError


@dataclass(unsafe_hash=True)
class PostByOrgReposInternalServerError(MesaError):
    r"""Internal error"""

    data: PostByOrgReposInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposConflictErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposConflictError


@dataclass(unsafe_hash=True)
class PostByOrgReposConflictError(MesaError):
    r"""Conflict"""

    data: PostByOrgReposConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposNotAcceptableErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposNotAcceptableError


@dataclass(unsafe_hash=True)
class PostByOrgReposNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: PostByOrgReposNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposNotFoundErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposNotFoundError


@dataclass(unsafe_hash=True)
class PostByOrgReposNotFoundError(MesaError):
    r"""Not found"""

    data: PostByOrgReposNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposForbiddenErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposForbiddenError


@dataclass(unsafe_hash=True)
class PostByOrgReposForbiddenError(MesaError):
    r"""Forbidden"""

    data: PostByOrgReposForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposUnauthorizedErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposUnauthorizedError


@dataclass(unsafe_hash=True)
class PostByOrgReposUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: PostByOrgReposUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class PostByOrgReposBadRequestErrorData(BaseModel):
    error: models_postbyorgreposop.PostByOrgReposBadRequestError


@dataclass(unsafe_hash=True)
class PostByOrgReposBadRequestError(MesaError):
    r"""Invalid request"""

    data: PostByOrgReposBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: PostByOrgReposBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
